@@ -1,13 +1,14 @@
 # -*- coding: utf-8 -*-
 '''
 
-    :copyright: (c) 2013 by Openlabs Technologies & Consulting (P) Ltd.
+    :copyright: (c) 2013-14 by Openlabs Technologies & Consulting (P) Ltd.
     :license: GPLv3, see LICENSE for more details
 
 '''
 from trytond.pool import Pool
 from webshop import WebShop, BannerCategory, Banner, Article
 from product import Product
+from invoice import Invoice
 
 
 def register():
@@ -17,5 +18,6 @@ def register():
         Banner,
         Article,
         Product,
+        Invoice,
         module='nereid_webshop', type_='model'
     )
